# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.2](https://github.com/conda/rattler/compare/rattler_libsolv_c-v1.0.1...rattler_libsolv_c-v1.0.2) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [1.0.1](https://github.com/conda/rattler/compare/rattler_libsolv_c-v1.0.0...rattler_libsolv_c-v1.0.1) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))
- use conda-incubator

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

## [0.19.5](https://github.com/conda/rattler/compare/rattler_libsolv_c-v0.19.4...rattler_libsolv_c-v0.19.5) - 2024-07-15

### Other
- bump dependencies and remove unused ones ([#771](https://github.com/conda/rattler/pull/771))

## [0.19.4](https://github.com/conda/rattler/compare/rattler_libsolv_c-v0.19.3...rattler_libsolv_c-v0.19.4) - 2024-07-08

### Other
- update README.md

## [0.19.3](https://github.com/conda/rattler/compare/rattler_libsolv_c-v0.19.2...rattler_libsolv_c-v0.19.3) - 2024-04-19

### Other
- update Cargo.toml dependencies

## [0.19.2](https://github.com/conda/rattler/compare/rattler_libsolv_c-v0.19.1...rattler_libsolv_c-v0.19.2) - 2024-03-14

### Other
- add pixi badge ([#563](https://github.com/conda/rattler/pull/563))

## [0.19.1](https://github.com/conda/rattler/compare/rattler_libsolv_c-v0.19.0...rattler_libsolv_c-v0.19.1) - 2024-03-06

### Other
- every crate should have its own version ([#557](https://github.com/conda/rattler/pull/557))

## [0.19.0](https://github.com/baszalmstra/rattler/compare/rattler_libsolv_c-v0.18.0...rattler_libsolv_c-v0.19.0) - 2024-02-26
